@@ -12,6 +12,7 @@ Configuration parameters:
         (default 60)
     charging_character: a character to represent charging battery
         especially useful when using icon fonts (e.g. FontAwesome)
+        set to 'None' if you want to hide the charging state of your battery
         (default "⚡")
     format: string that formats the output. See placeholders below.
         (default "{icon}")
@@ -21,6 +22,16 @@ Configuration parameters:
     format_notify_discharging: format of the notification received when you
         click on the module while your computer is not plugged in
         (default "{time_remaining}")
+    format_status_bad: a string to put in {status} when bad
+        (default "CRIT")
+    format_status_charging: a string to put in {status} when charging
+        (default "CHG")
+    format_status_degraded: a string to put in {status} when degraded
+        (default "LOW")
+    format_status_discharging: a string to put in {status} when discharging
+        (default "BAT")
+    format_status_full: a string to put in {status} when full
+        (default "FULL")
     hide_seconds: hide seconds in remaining time
         (default False)
     hide_when_full: hide any information when battery is fully charged (when
@@ -59,6 +70,7 @@ Format placeholders:
     {percent} - the remaining battery percentage (previously '{}')
     {time_remaining} - the remaining time until the battery is empty
     {power} - the current power consumption in Watts. Not working with acpi.
+    {status} - the current battery status string as defined by 'format_status_*'
 
 Color options:
     color_bad: Battery level is below threshold_bad
@@ -96,6 +108,11 @@ FULL_BLOCK = "█"
 FORMAT = "{icon}"
 FORMAT_NOTIFY_CHARGING = "Charging ({percent}%)"
 FORMAT_NOTIFY_DISCHARGING = "{time_remaining}"
+FORMAT_STATUS_BAD = "CRIT"
+FORMAT_STATUS_CHARGING = "CHG"
+FORMAT_STATUS_DEGRADED = "LOW"
+FORMAT_STATUS_DISCHARGING = "BAT"
+FORMAT_STATUS_FULL = "FULL"
 SYS_BATTERY_PATH = "/sys/class/power_supply/"
 MEASUREMENT_MODE = None
 FULLY_CHARGED = "?"
@@ -112,6 +129,11 @@ class Py3status:
     format = FORMAT
     format_notify_charging = FORMAT_NOTIFY_CHARGING
     format_notify_discharging = FORMAT_NOTIFY_DISCHARGING
+    format_status_bad = FORMAT_STATUS_BAD
+    format_status_charging = FORMAT_STATUS_CHARGING
+    format_status_degraded = FORMAT_STATUS_DEGRADED
+    format_status_discharging = FORMAT_STATUS_DISCHARGING
+    format_status_full = FORMAT_STATUS_FULL
     hide_seconds = False
     hide_when_full = False
     measurement_mode = MEASUREMENT_MODE
@@ -183,6 +205,7 @@ class Py3status:
         self._refresh_battery_info(battery_list)
         self._update_icon()
         self._update_ascii_bar()
+        self._update_status()
         self._update_full_text()
 
         return self._build_response()
@@ -262,9 +285,17 @@ class Py3status:
         # Separate the output because each pair of lines corresponds to a
         # single battery.  Now the list index will correspond to the index of
         # the battery we want to look at
-        acpi_list = [acpi_list[i : i + 2] for i in range(0, len(acpi_list) - 1, 2)]
+        temporary = {}
+        for line in acpi_list:
+            number = line.split(":", 1)[0].strip("Battery ")
+            temporary.setdefault(number, []).append(line)
 
-        return [_parse_battery_info(battery) for battery in acpi_list]
+        new_acpi = {}
+        for k, v in temporary.items():
+            if "rate information unavailable" not in "|".join(v):
+                new_acpi[k] = v
+
+        return [_parse_battery_info(battery) for battery in new_acpi.values()]
 
     def _extract_battery_info_from_sys(self):
         """
@@ -316,7 +347,9 @@ class Py3status:
             remaining_energy = r.get(
                 "POWER_SUPPLY_ENERGY_NOW", r.get("POWER_SUPPLY_CHARGE_NOW")
             )
-            current_now = r.get("POWER_SUPPLY_CURRENT_NOW", 0)
+            current_now = r.get(
+                "POWER_SUPPLY_CURRENT_NOW", r.get("POWER_SUPPLY_POWER_NOW", 0)
+            )
             voltage_now = r.get("POWER_SUPPLY_VOLTAGE_NOW", 0)
 
             # missing values may indicate this is not a battery and should be skipped
@@ -343,7 +376,7 @@ class Py3status:
                     time_in_secs = remaining_energy / present_rate * 3600
                 battery["time_remaining"] = self._seconds_to_hms(time_in_secs)
 
-            battery["power"] = current_now * voltage_now / 10 ** 12
+            battery["power"] = current_now * voltage_now / 10**12
 
             battery_list.append(battery)
         return battery_list
@@ -440,8 +473,20 @@ class Py3status:
                 10 - self.percent_charged // 10
             )
 
-    def _update_icon(self):
+    def _update_status(self):
         if self.charging:
+            self.status = self.format_status_charging
+        elif self.percent_charged < self.threshold_bad:
+            self.status = self.format_status_bad
+        elif self.percent_charged < self.threshold_degraded:
+            self.status = self.format_status_degraded
+        elif self.percent_charged >= self.threshold_full:
+            self.status = self.format_status_full
+        else:
+            self.status = self.format_status_discharging
+
+    def _update_icon(self):
+        if self.charging and self.charging_character is not None:
             self.icon = self.charging_character
         else:
             self.icon = self.blocks[
@@ -460,6 +505,7 @@ class Py3status:
                 percent=self.percent_charged,
                 time_remaining=self.time_remaining,
                 power=self.power_now,
+                status=self.status,
             ),
         )
 
