@@ -15,7 +15,7 @@ Configuration parameters:
         False: disable Do Not Disturb on startup
         True: enable Do Not Disturb on startup
         last: toggle last known state on startup
-        None: query current state from notification manager (doesn't work on dunst)
+        None: query current state from notification manager (doesn't work on dunst<1.5.0)
         (default 'last')
     thresholds: specify color thresholds to use
         (default [(0, 'bad'), (1, 'good')])
@@ -35,6 +35,14 @@ Dunst Miscellaneous:
     This means that by default (pause = False), all notifications sent while
     DND is active will NOT be queued and displayed when DND is deactivated.
 
+Mako Miscellaneous:
+    Mako requires that you manually create a 'do-not-disturb' mode as shown
+    in https://man.voidlinux.org/mako.5#MODES.
+    This module expects this mode to be configured by the user as suggested by
+    the mako documentation:
+    [mode=do-not-disturb]
+    invisible=1
+
 
 Examples:
 ```
@@ -89,8 +97,22 @@ class Dunst(Notification):
     Dunst Notification.
     """
 
+    def setup(self, parent):
+        self.has_dunstctl = bool(self.parent.py3.check_commands(["dunstctl"]))
+
+    def get_state(self):
+        if self.has_dunstctl:
+            state = self.parent.py3.command_output("dunstctl is-paused")
+            return state.strip() == "true"
+        else:
+            return self.parent.state
+
     def toggle(self, state):
-        if state:
+        if self.has_dunstctl:
+            self.parent.py3.command_run(
+                "dunstctl set-paused {}".format(str(state).lower())
+            )
+        elif state:
             # pause
             self.parent.py3.command_run("pkill -SIGUSR1 dunst")
         else:
@@ -107,8 +129,24 @@ class Mako(Notification):
     Mako Notification.
     """
 
+    # From version mako 1.7 we can use "makoctl mode"
+    def setup(self, parent):
+        self.has_makoctl_mode = bool(
+            self.parent.py3.check_commands(["makoctl"])
+        ) and not self.parent.py3.command_run("makoctl mode")
+
+    def get_state(self):
+        if self.has_makoctl_mode:
+            state = self.parent.py3.command_output("makoctl mode")
+            return state.strip() == "do-not-disturb"
+        else:
+            return self.parent.state
+
     def toggle(self, state):
-        self.parent.py3.command_run("makoctl set invisible={}".format(int(state)))
+        if state is True:
+            self.parent.py3.command_run("makoctl set-mode do-not-disturb")
+        else:
+            self.parent.py3.command_run("makoctl set-mode default")
 
 
 class Xfce4_notifyd(Notification):
@@ -132,8 +170,7 @@ class Xfce4_notifyd(Notification):
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 30
@@ -177,7 +214,7 @@ class Py3status:
                 self.backend.toggle(self.state)
             else:
                 raise Exception(STRING_INVALID_STATE.format(self.state))
-        elif self.server == "dunst":
+        elif self.server == "dunst" and not self.backend.has_dunstctl:
             raise Exception(STRING_INVALID_STATE.format(self.state))
 
         self.name = self.server.capitalize()
