@@ -25,6 +25,8 @@ Configuration parameters:
         (default 1)
     cache_timeout: How often the module is refreshed in seconds
         (default 60)
+    calendar_id: The ID of the calendar to display.
+        (default "primary")
     client_secret: the path to your client_secret file which
         contains your OAuth 2.0 credentials.
         (default '~/.config/py3status/google_calendar.client_secret')
@@ -154,7 +156,6 @@ import httplib2
 import datetime
 import time
 from pathlib import Path
-from html import escape
 
 try:
     from googleapiclient import discovery
@@ -173,8 +174,7 @@ APPLICATION_NAME = "py3status google_calendar module"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     auth_token = "~/.config/py3status/google_calendar.auth_token"
@@ -184,6 +184,7 @@ class Py3status:
     button_refresh = 2
     button_toggle = 1
     cache_timeout = 60
+    calendar_id = "primary"
     client_secret = "~/.config/py3status/google_calendar.client_secret"
     events_within_hours = 12
     force_lowercase = False
@@ -286,7 +287,7 @@ class Py3status:
             eventsResult = (
                 self.service.events()
                 .list(
-                    calendarId="primary",
+                    calendarId=self.calendar_id,
                     timeMax=time_max.isoformat() + "Z",  # 'Z' indicates UTC time
                     timeMin=time_min.isoformat() + "Z",  # 'Z' indicates UTC time
                     singleEvents=True,
@@ -343,15 +344,15 @@ class Py3status:
             self.py3.notify_user(warn_message, "warning", self.warn_timeout)
 
     def _gstr_to_date(self, date_str):
-        """ Returns a dateime object from calendar date string."""
+        """Returns a dateime object from calendar date string."""
         return parser.parse(date_str).replace(tzinfo=tzlocal())
 
     def _gstr_to_datetime(self, date_time_str):
-        """ Returns a datetime object from calendar date/time string."""
+        """Returns a datetime object from calendar date/time string."""
         return parser.parse(date_time_str)
 
     def _datetime_to_str(self, date_time, dt_format):
-        """ Returns a strftime formatted string from a datetime object."""
+        """Returns a strftime formatted string from a datetime object."""
         return date_time.strftime(dt_format)
 
     def _delta_time(self, date_time):
@@ -412,7 +413,7 @@ class Py3status:
 
             event_dict = {}
 
-            event_dict["summary"] = escape(event.get("summary"))
+            event_dict["summary"] = event.get("summary")
             event_dict["location"] = event.get("location")
             event_dict["description"] = event.get("description")
             self.event_urls.append(
